"use strict";
// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Task = void 0;
/**
 * Abstract base class for asynchronous tasks in a durable orchestration.
 */
class Task {
    constructor() {
        this._isComplete = false;
        this._isComplete = false;
        this._exception = undefined;
        this._parent = undefined;
    }
    /**
     * Returns true if the task has completed, false otherwise
     */
    get isComplete() {
        return this._isComplete;
    }
    /**
     * Returns true if the task has failed, false otherwise
     */
    get isFailed() {
        return this._exception != undefined;
    }
    /**
     * Get the result of the task
     */
    getResult() {
        if (!this._isComplete) {
            throw new Error("Task is not complete");
        }
        if (this._exception) {
            throw this._exception;
        }
        return this._result;
    }
    /**
     * Get the exception that caused the task to fail
     */
    getException() {
        if (!this._exception) {
            throw new Error("Task did not fail");
        }
        return this._exception;
    }
}
exports.Task = Task;
